@@ -68,15 +68,24 @@ dTrainN$y <- 1000*(dTrainN$x1 + dTrainN$x2)
 cEraw <- vtreat::mkCrossFrameNExperiment(dTrainN,
                                          c('x1','x2','x3'),'y',
                                          scale=TRUE)
-dM1 <- as.matrix(cEraw$crossFrame[,c('x1_clean','x2_clean','x3_clean')])
+
+newvars <- cEraw$treatments$scoreFrame$varName
+print(newvars)
+
+dM1 <- as.matrix(cEraw$crossFrame[, newvars])
 pCraw <- stats::prcomp(dM1,
                        scale.=FALSE,center=TRUE)
 print(pCraw)
+
 dTrainN$yScaled <- scale(dTrainN$y,center=TRUE,scale=TRUE)
 cEscaled <- vtreat::mkCrossFrameNExperiment(dTrainN,
                                             c('x1','x2','x3'),'yScaled',
                                             scale=TRUE)
-dM2 <- as.matrix(cEscaled$crossFrame[,c('x1_clean','x2_clean','x3_clean')])
+newvars_s <- cEscaled$treatments$scoreFrame$varName
+print(newvars_s)
+
+
+dM2 <- as.matrix(cEscaled$crossFrame[, newvars_s])
 pCscaled <- stats::prcomp(dM2,
                           scale.=FALSE,center=TRUE)
 print(pCscaled)
